---
title: <span class="badge object-type-scalar"></span> MicroFarad
---
# <span class="badge object-type-scalar"></span> MicroFarad

Energy: Microfarad (µF)

## Definition

```python
# Energy: Microfarad (µF)
MicroFarad: typing.Literal["watt"] = "watt"
```
